import request from '@/utils/request'

// 查询流程模板列表
export function listPROTEMPLATE(query) {
  return request({
    url: '/proTemplate/list',
    method: 'get',
    params: query
  })
}

// 查询流程模板所有列表
export function listAllPROTEMPLATE(query) {
  return request({
    url: '/proTemplate/listAll',
    method: 'get',
    params: query
  })
}

// 查询流程模板详细
export function getPROTEMPLATE(id) {
  return request({
    url: '/proTemplate/getInfo/' + id,
    method: 'get'
  })
}

// 新增流程模板
export function addPROTEMPLATE(data) {
  return request({
    url: '/proTemplate/add',
    method: 'post',
    data: data
  })
}

// 修改流程模板
export function updatePROTEMPLATE(data) {
  return request({
    url: '/proTemplate/edit',
    method: 'post',
    data: data
  })
}

// 删除流程模板
export function delPROTEMPLATE(id) {
  return request({
    url: '/proTemplate/remove/' + id,
    method: 'get'
  })
}

// 获取流程节点
export function getProcode(id) {
  return request({
    url: '/defAction/list',
    method: 'get',
    params: {proId : id}
  })
}


// 获取流程节点
export function delPro(id) {
  return request({
    url: '/defAction/remove/' + id,
    method: 'get'
  })
}


// 获取流程节点详情
export function getProInfo(id) {
  return request({
    url: '/defAction/getInfo/' + id,
    method: 'get'
  })
}


// 新增流程节点
export function addPro(data) {
  return request({
    url: '/defAction/add',
    method: 'post',
    data: data
  })
}

// 修改流程节点
export function updatePro(data) {
  return request({
    url: '/defAction/edit',
    method: 'post',
    data: data
  })
}

// 获取用户列表
export function getUser() {
  return request({
    url: '/test/user/list',
    method: 'get',
  })
}
// 流程开关
export function enableOrDisable(data) {
  return request({
    url: '/proTemplate/type',
    method: 'post',
    data:data
  })
}


